# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
import urlparse

from frontend.tests.test_clientresponse import ClientResponseTestsGeneral


class AndroidBuildClientResponseTests(ClientResponseTestsGeneral):

    def setUp(self):
        super(AndroidBuildClientResponseTests, self).setUp()
        self.android_build_data = {"name": "a-build",
                                   "build_type": "build-android",
                                   "manifest_repo": "repo",
                                   "manifest_branch": "branch",
                                   "manifest_filename": "filename",
                                   "make_jobs": "2",
                                   "ramdisk_size": "2",
                                   "binutils_version": "1",
                                   "gcc_version": "1",
                                   "next_loop_0" : "",
                                    }

    def test_android_build_create_get(self):
        self.client.login(username=self.user, password=self.passwd)
        response = self.client.get("/android/create/")
        self.assertIn("/android/create/", response.content)
        template_names = [template.name for template in
                          response.templates]
        self.assertEquals(template_names, ["android_loop_create.html",
                                           "base.html",
                                           "login.html",
                                           ])

    def test_android_build_create_post_no_data(self):
        self.client.login(username=self.user, password=self.passwd)
        response = self.client.post("/android/create/", {})
        self.assertEquals(response.status_code, 200)
        self.assertIn("This field is required", response.content)

    def test_android_build_create_post(self):
        self.client.login(username=self.user, password=self.passwd)

        # Follow redirect after save.
        response = self.client.post("/android/create/",
                                    self.android_build_data, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        # Assert content for required fields filled
        self.assertNotIn("This field is required", response.content)
        # Assert template names for detail page.
        template_names = [template.name for template in
                          response.templates]
        self.assertEquals(template_names, ["android_loop_detail.html",
                                           "base.html",
                                           "login.html",
                                           ])
        # Assert if everything is present on detail page.
        self.assertIn(self.android_build_data["name"], response.content)
        self.assertIn(self.android_build_data["build_type"], response.content)

    def test_android_build_detail_get(self):
        self.client.login(username=self.user, password=self.passwd)

        # Follow redirect after save.
        target_file = "/android/create/"
        url = urlparse.urljoin("http://testserver/", target_file)
        response = self.client.post(url, self.android_build_data, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        # Assert content for required fields filled
        self.assertNotIn("This field is required", response.content)

        target_file = "/android/detail/%s/" % self.android_build_data["name"]
        url = urlparse.urljoin("http://testserver/", target_file)
        response = self.client.get(url, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        self.assertIn("Details", response.content)
        self.assertIn("Build type", response.content)
