# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
from django.test import TestCase
from mock import MagicMock

from frontend.android_build.views.android_loop_create_view \
    import AndroidLoopCreateView
from frontend.android_build.views.android_loop_detail_view \
    import AndroidLoopDetailView
from frontend.android_build.views.android_loop_update_view\
    import AndroidLoopUpdateView


class AndroidBuildViewsTest(TestCase):

    def setUp(self):
        self.mock_loop = MagicMock()
        self.mock_loop.loop_ptr = MagicMock()
        self.mock_loop.loop_ptr.id = 0
        self.mock_loop.loop_ptr.loopbuild_set = MagicMock()
        self.mock_loop.loop_ptr.loopbuild_set.all = MagicMock()

    def test_create_view_get_context_data(self):
        android_loop_create_view = AndroidLoopCreateView()
        android_loop_create_view.request = "some request data"
        android_loop_create_view.object = self.mock_loop
        context = AndroidLoopCreateView.get_context_data(
            android_loop_create_view)
        self.assertEqual(context['request'], "some request data")
        self.assertEqual(context['form_name'], AndroidLoopCreateView.form_name)

    def test_detail_view_get_context_data(self):
        android_loop_detail_view = AndroidLoopDetailView()
        android_loop_detail_view.request = "some request data"
        android_loop_detail_view.object = self.mock_loop
        context = AndroidLoopDetailView.get_context_data(
            android_loop_detail_view)
        self.assertEqual(context['request'], "some request data")
        self.assertEqual(context['builds'].__class__.__name__, "MagicMock")
        self.assertEqual(context['data'].__class__.__name__, "list")

    def test_update_view_get_context_data(self):
        android_loop_update_view = AndroidLoopUpdateView()
        android_loop_update_view.request = "some request data"
        android_loop_update_view.object = self.mock_loop
        context = AndroidLoopUpdateView.get_context_data(
            android_loop_update_view)
        self.assertEqual(context['request'], "some request data")
        self.assertEqual(context['form_name'], AndroidLoopUpdateView.form_name)
