#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.views.generic.detail import DetailView
from django.utils.decorators import method_decorator
from frontend.models.loop import Loop
from frontend.android_build.models.android_loop import AndroidLoop
from django.core import serializers
from itertools import chain


class AndroidLoopDetailView(DetailView):

    model = AndroidLoop
    context_object_name = 'android_loop_detail'
    slug_field = "name"
    template_name = "android_loop_detail.html"

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(AndroidLoopDetailView, self).dispatch(*args, **kwargs)

    def get_context_data(self, **kwargs):
        '''Get the context data passed to template.'''
        context = super(AndroidLoopDetailView,
                        self).get_context_data(**kwargs)
        context['request'] = self.request
        context['builds'] = self.object.loop_ptr.loopbuild_set.all()

        # Need to "merge" the two queryset for all the fields to appear
        querysets = list(chain(AndroidLoop.objects.filter(
                               pk=self.object.loop_ptr.id),
                               Loop.objects.filter(pk=self.object.loop_ptr.id)))
        context['data'] = serializers.serialize("python", querysets)

        return context
