# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.test import TestCase
from frontend.android_textfield_loop.models.android_textfield_loop \
    import AndroidTextFieldLoop


class AndroidTextFieldLoopModelTest(TestCase):

    A_NAME = 'a-build'
    B_NAME = 'b-build'
    VALID_VALUES = 'a=2\nb=3'
    VALID_LINES = ['a=2', 'b=3']
    NON_VALID_VALUES = 'a:2\nb=3'
    NON_VALID_LINES = ['a:2', 'b=3']
    VALID_DICT = {'a': '2', 'b': '3'}

    def setUp(self):
        self.android_loop = AndroidTextFieldLoop.objects.create(
            name=self.A_NAME,
            values=self.VALID_VALUES)
        self.non_valid_android_loop = \
            AndroidTextFieldLoop.objects.create(name=self.B_NAME,
                                                values=self.NON_VALID_VALUES)

    def test_values_to_dict_correct(self):
        self.assertEqual(self.VALID_DICT,
                         self.android_loop.values_to_dict())

    def test_values_to_dict_wrong(self):
        self.assertEqual({}, self.non_valid_android_loop.values_to_dict())

    def test_valid_values_correct(self):
        self.assertEqual(AndroidTextFieldLoop.valid_values(self.VALID_VALUES),
                         (True, self.VALID_LINES))

    def test_valid_values_wrong(self):
        self.assertEqual((False, self.NON_VALID_LINES),
                         AndroidTextFieldLoop.valid_values(
                             self.NON_VALID_VALUES))