# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.core.urlresolvers import reverse
from django.views.generic.edit import UpdateView
from django.utils.decorators import method_decorator
from frontend.android_textfield_loop.models.android_textfield_loop \
    import AndroidTextFieldLoop
from frontend.android_textfield_loop.forms.android_textfield_loop_form \
    import AndroidTextFieldLoopForm


class AndroidTextFieldLoopUpdateView(UpdateView):

    template_name = "android_textfield_loop_update.html"
    form_class = AndroidTextFieldLoopForm
    context_object_name = 'android_loop_update'
    model = AndroidTextFieldLoop
    slug_field = "name"
    form_name = 'android_textfield_loop'

    def form_valid(self, form):
        """This method is called when valid form data has been POSTed.

        It should return an HttpResponse."""
        return super(AndroidTextFieldLoopUpdateView, self).form_valid(form)

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(AndroidTextFieldLoopUpdateView,
                     self).dispatch(*args, **kwargs)

    def get_context_data(self, **kwargs):
        '''Get the context data passed to template.'''
        context = super(AndroidTextFieldLoopUpdateView,
                        self).get_context_data(**kwargs)
        context['request'] = self.request
        context['form_name'] = self.form_name
        return context

    def get_success_url(self):
        '''Return the URL when the form is valid.'''
        return reverse('AndroidTextFieldLoopDetail', args=[self.object.name])
