#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from frontend.models.loop import Loop
from jenkinsserver.models.jenkins_server import JenkinsServer


LLT_URL = (r'git://git.linaro.org/kernel/linux-linaro-tracking.git',
          'Linux Linaro Tracking')
LN_URL = (r'git://git.kernel.org/pub/scm/linux/kernel/git/next/linux-next.git',
          'Linux Next')
LM_URL = (r'git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git',
          'Linux Master')
LARM_URL = (r'git://git.kernel.org/pub/scm/linux/kernel/git/arm/arm-soc.git',
           'Linux ARM SoC')

REPO_URLS = (LLT_URL, LN_URL, LM_URL, LARM_URL)

# Kernel branches names
MASTER = (r'master',  'Master Branch')
FOR_NEXT = (r'for-next', 'for-next Branch')
LLT = (r'linux-linaro-tracking', 'linux-linaro-tracking Branch')
LL = (r'linux-linaro', 'linux-linaro Branch')

REPO_BRANCHES = (MASTER, FOR_NEXT, LLT, LL)

#Internal name of the board, and a user visible name
BEAGLEBOARD = (r'beagleboard', 'Beagleboard')
PANDABOARD = (r'panda', 'Pandaboard')
SNOWBALL = (r'snowball', 'Snowball')
VEXPRESS = (r'vexpress', 'Vexpress')
# The supported boards for the build.
HWPACK_TYPES = (BEAGLEBOARD, PANDABOARD, SNOWBALL, VEXPRESS)

#LAVA board names
SNOWBALL = (r'snowball_sd', 'Snowball')
BOARD_TYPES = (BEAGLEBOARD, PANDABOARD, SNOWBALL, VEXPRESS)

# Kernel Config names
KERNEL_CONFIGS = (
                   (r'omap2plus_defconfig', 'omap2plus'),
                   (r'u8500_defconfig', 'u8500'),
                   (r'exynos4_defconfig', 'exynos4'),
                   (r'vexpress_defconfig', 'vexpress'),
                 )

# ROOTFS types
ROOTFS_TYPES = (
                 (r'nano', 'Nano image'),
                 (r'developer', 'Developer image'),
               )

#Kernel Flavours
KERNEL_FLAVOURS = (
                    (r'omap', 'Omap'),
                    (r'origen', 'Origen'),
                    (r'vexpress', 'Vexpress'),
                    (r'u8500', 'U8500'),
                  )


class KernelLoop(Loop):
    class Meta:
        app_label = 'kernel_build'

    # The default values used by the build scripts
    DEFAULT_KERNEL_CONFIG = 'omap2plus_defconfig'
    DEFAULT_HWPACK_TYPE = DEFAULT_BOARD_TYPE = PANDABOARD
    DEFAULT_KERNEL_FLAVOUR = 'omap'
    DEFAULT_ROOTFS_TYPE = 'nano'

    # The branch containing the build scripts used for kernel builds
    build_tools_branch = models.CharField(max_length=200,
                                          default='lp:linaro-ci')

    # GIT REPO
    kernel_git_repo = models.CharField(max_length=255, choices=REPO_URLS,
                                      default=LLT_URL)
    # GIT REPO BRANCH
    kernel_branch = models.CharField(max_length=100, choices=REPO_BRANCHES,
                                     default=LL)
    # KERNEL CONFIGS
    kernel_config = models.CharField(max_length=100, choices=KERNEL_CONFIGS,
                                    default=DEFAULT_KERNEL_CONFIG)
    # HWPACK_TYPE
    hwpack_type = models.CharField(max_length=50, choices=HWPACK_TYPES,
                                   default=DEFAULT_HWPACK_TYPE)
    # BOARD TYPE
    board_type = models.CharField(max_length=50, choices=BOARD_TYPES,
                                  default=DEFAULT_BOARD_TYPE)
    # KERNEL FLAVOUR
    kernel_flavour = models.CharField(max_length=50, choices=KERNEL_FLAVOURS,
                                  default=DEFAULT_KERNEL_FLAVOUR)

    # ROOTFS TYPES
    rootfs_type = models.CharField(max_length=100, choices=ROOTFS_TYPES,
                                   default=DEFAULT_ROOTFS_TYPE)

    def save(self, *args, **kwargs):
        self.server = JenkinsServer.objects.get(id=1)
        self.type = self.__class__.__name__
        super(self.__class__, self).save(*args, **kwargs)
        # We do not want a failure in remote server to affect the
        # CI Loop flow.
        try:
            self.server.create_or_update_loop(self)
        except:
            # TODO: Log error.
            pass
