# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
import urlparse

from frontend.tests.test_clientresponse import ClientResponseTestsGeneral


class KernelBuildClientResponseTests(ClientResponseTestsGeneral):

    def setUp(self):
        super(KernelBuildClientResponseTests, self).setUp()
        self.kernel_build_data = {"name": "kernel_build", 
                                  "kernel_git_repo": \
                      "git://git.linaro.org/kernel/linux-linaro-tracking.git", 
                                  "rootfs_type": "nano", 
                                  "loop_ptr": 1, 
                                  "server": 1, 
                                  "build_tools_branch": "linaro-ci", 
                                  "board_type": "panda", 
                                  "hwpack_type": "panda", 
                                  "kernel_config": "omap2plus_defconfig", 
                                  "kernel_branch": "linux-linaro", 
                                  "id": 1, 
                                  "kernel_flavour": "omap",
                                  "next_loop_0": "",
                                  }

    def test_kernel_build_create_get(self):
        self.client.login(username=self.user, password=self.passwd)
        response = self.client.get("/kernel/create/")
        self.assertIn("/kernel/create/", response.content)
        template_names = [template.name for template in
                          response.templates]
        self.assertEquals(template_names, ["kernel_loop_create.html",
                                           "base.html",
                                           "login.html",
                                           ])

    def test_kernel_build_create_post_no_data(self):
        self.client.login(username=self.user, password=self.passwd)
        response = self.client.post("/kernel/create/", {})
        self.assertEquals(response.status_code, 200)
        self.assertIn("This field is required", response.content)

    def test_kernel_build_create_post(self):
        self.client.login(username=self.user, password=self.passwd)

        # Follow redirect after save.
        response = self.client.post("/kernel/create/",
                                    self.kernel_build_data, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        # Assert content for required fields filled
        self.assertNotIn("This field is required", response.content)
        # Assert template names for detail page.
        template_names = [template.name for template in
                          response.templates]
        self.assertEquals(template_names, ["kernel_loop_detail.html",
                                           "base.html",
                                           "login.html",
                                           ])
        # Assert if everything is present on detail page.
        for key in self.kernel_build_data.iterkeys():
            self.assertIn(str(self.kernel_build_data[key]), response.content)

        
    def test_kernel_build_create_repost_error(self):
        self.client.login(username=self.user, password=self.passwd)

        # Follow redirect after save.
        response = self.client.post("/kernel/create/",
                                    self.kernel_build_data, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        response = self.client.post("/kernel/create/",
                                    self.kernel_build_data, follow=True)
        self.assertIn("Loop with this Name already exists.", response.content)


    def test_kernel_build_detail_get(self):
        self.client.login(username=self.user, password=self.passwd)

        # Follow redirect after save.
        target_file = "/kernel/create/"
        url = urlparse.urljoin("http://testserver/", target_file)
        response = self.client.post(url, self.kernel_build_data, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        # Assert content for required fields filled
        self.assertNotIn("This field is required", response.content)

        target_file = "/kernel/detail/%s/" % self.kernel_build_data["name"]
        url = urlparse.urljoin("http://testserver/", target_file)
        response = self.client.get(url, follow=True)
        # Assert response code.
        self.assertEquals(response.status_code, 200)
        self.assertIn("Details", response.content)
