#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.core.urlresolvers import reverse
from django.views.generic.edit import UpdateView
from django.utils.decorators import method_decorator
from frontend.kernel_build.forms.kernel_loop_form \
    import KernelLoopForm
from frontend.kernel_build.models.kernel_loop import KernelLoop


class KernelLoopUpdateView(UpdateView):

    template_name = "kernel_loop_update.html"
    form_class = KernelLoopForm
    context_object_name = 'kernel_loop_update'
    model = KernelLoop
    slug_field = "name"

    def form_valid(self, form):
        """This method is called when valid form data has been POSTed.

        It should return an HttpResponse."""

        return super(KernelLoopUpdateView, self).form_valid(form)

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(KernelLoopUpdateView, self).dispatch(*args, **kwargs)

    def get_context_data(self, **kwargs):
        '''Get the context data passed to template.'''
        context = super(KernelLoopUpdateView,
                        self).get_context_data(**kwargs)
        context['request'] = self.request
        return context

    def get_success_url(self):
        '''Return the URL when the form is valid.'''
        return reverse('KernelLoopDetail', args=[self.object.name])
