#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.db import models
from frontend.models.loop import Loop


class LoopBuild(models.Model):
    class Meta:
        app_label = 'frontend'
        ordering = ['-id']

    BUILD_STATUS = (
        ('scheduled', 'SCHEDULED'),
        ('running', 'RUNNING'),
        ('failure', 'FAILURE'),
        ('success', 'SUCCESS'),
        ('aborted', 'ABORTED'),
    )
    loop = models.ForeignKey(Loop)
    build_number = models.IntegerField(default=None)
    remote_number = models.IntegerField(null=True, blank=True)
    status = models.CharField(max_length=20, choices=BUILD_STATUS)
    duration = models.DecimalField(max_digits=8, decimal_places=2)

    def save(self, *args, **kwargs):
        loop_builds = LoopBuild.objects.filter(loop=self.loop).order_by("-id")
        if not self.build_number:
            if loop_builds:
                self.build_number = loop_builds[0].build_number + 1
            else:
                self.build_number = 1
        super(LoopBuild, self).save(*args, **kwargs)
