#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
from django.db.models import get_models
from django.test import TestCase
from mock import Mock, patch

from frontend.models.loop import Loop
from frontend.integration_loop.models.integration_loop import IntegrationLoop
from frontend.android_build.models.android_loop import AndroidLoop
from frontend.android_textfield_loop.models.android_textfield_loop \
  import AndroidTextFieldLoop
from lib.model_getter import ModelGetter

class LoopTest(TestCase):

    def setUp(self):
        super(LoopTest, self).setUp()
        self.integration_loop = IntegrationLoop()
        self.integration_loop.name = "testjob_integration"
        self.integration_loop.branch = "lp:linaro-ci-dashboard"
        self.integration_loop.precommand = "make migrate"
        self.integration_loop.command = "make test"
        self.integration_loop.save()

        self.android_loop = AndroidLoop()
        self.android_loop.name = "testjob_android"
        self.android_loop.build_type = "build-android"
        self.android_loop.save()

    def test_get_child_object(self):
        loop = Loop.objects.get(id=1)
        self.assertEqual("testjob_integration", loop.get_child_object().name)
        self.assertEqual("make migrate", loop.get_child_object().precommand)
        self.assertEqual("IntegrationLoop",
                         loop.get_child_object().__class__.__name__)


    def test_get_all_chainable_integration_empty(self):
        chainable_loops = IntegrationLoop.get_all_chainable()
        # Integration loop does not have any chainable loops
        self.assertEqual(0, len(chainable_loops))

    def test_get_all_chainable_android_text(self):
        chainable_loops = AndroidTextFieldLoop.get_all_chainable()
        self.assertEqual(1, len(chainable_loops))
        self.assertEqual("AndroidLoop", chainable_loops[0].type)
        self.assertEqual("testjob_android", chainable_loops[0].name)

    def test_model_getter_unique_model(self):
        all_models = [model.__name__ for model in get_models()]
        self.assertTrue(len(all_models) == len(set(all_models)))
