#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
from django.test import TestCase
from mock import Mock, patch

from frontend.views.home_page_view import HomePageView
from frontend.views.index_view import IndexView
from frontend.integration_loop.views.integration_loop_create_view \
    import IntegrationLoopCreateView
from frontend.integration_loop.views.integration_loop_update_view \
    import IntegrationLoopUpdateView
from frontend.integration_loop.views.integration_loop_detail_view \
    import IntegrationLoopDetailView


class HomePageViewTest(TestCase):

    def test_get_context_data(self):
        home_page_view = HomePageView()
        home_page_view.request = "some request data"
        context = HomePageView.get_context_data(home_page_view)
        self.assertEqual(context['request'], "some request data")


class IndexViewTest(TestCase):

    def test_get_context_data(self):
        index_view = IndexView()
        index_view.request = "some request data"
        context = IndexView.get_context_data(index_view)
        self.assertEqual(context['request'], "some request data")


class IntegrationLoopCreateViewTest(TestCase):

    def setUp(self):
        self.mock_loop = Mock()

    def test_get_context_data(self):
        integration_loop_create_view = IntegrationLoopCreateView()
        integration_loop_create_view.request = "some request data"
        integration_loop_create_view.object = self.mock_loop
        context = IntegrationLoopCreateView.get_context_data(
            integration_loop_create_view)
        self.assertEqual(context['request'], "some request data")


class IntegrationLoopDetailViewTest(TestCase):

    def setUp(self):
        self.mock_loop = Mock()
        self.mock_loop.loop_ptr = Mock()
        self.mock_loop.loop_ptr.loopbuild_set = Mock()
        self.mock_loop.loop_ptr.loopbuild_set.all = Mock()

    def test_get_context_data(self):
        integration_loop_detail_view = IntegrationLoopDetailView()
        integration_loop_detail_view.request = "some request data"
        integration_loop_detail_view.object = self.mock_loop
        context = IntegrationLoopDetailView.get_context_data(
            integration_loop_detail_view)
        self.assertEqual(context['request'], "some request data")
        self.assertEqual(context['builds'].__class__.__name__, "Mock")


class IntegrationLoopUpdateViewTest(TestCase):

    def setUp(self):
        self.mock_loop = Mock()

    def test_get_context_data(self):
        integration_loop_update_view = IntegrationLoopUpdateView()
        integration_loop_update_view.request = "some request data"
        integration_loop_update_view.object = self.mock_loop
        context = IntegrationLoopUpdateView.get_context_data(
            integration_loop_update_view)
        self.assertEqual(context['request'], "some request data")
