#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.views.generic.base import TemplateView
from django.utils.decorators import method_decorator
from django.contrib.auth.decorators import login_required
from frontend.integration_loop.models.integration_loop import IntegrationLoop
from frontend.android_build.models.android_loop import AndroidLoop
from frontend.kernel_build.models.kernel_loop import KernelLoop
from frontend.android_textfield_loop.models.android_textfield_loop \
    import AndroidTextFieldLoop


class IndexView(TemplateView):

    template_name = "index.html"

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(IndexView, self).dispatch(*args, **kwargs)

    def get_context_data(self, **kwargs):
        context = super(IndexView, self).get_context_data(**kwargs)
        context['request'] = self.request
        context['integration_loops'] = IntegrationLoop.objects.all()
        context['android_loops'] = AndroidLoop.objects.all()
        context['kernel_loops'] = KernelLoop.objects.all()
        context['android_textfield_loops'] = AndroidTextFieldLoop.objects.all()
        return context
