#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.views.generic.list import ListView
from django.utils.decorators import method_decorator
from frontend.models.loop import Loop
from lib.model_getter import ModelGetter

class LoopGetChainableView(ListView):

    model = Loop

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(LoopGetChainableView, self).dispatch(*args, **kwargs)

    def render_to_response(self, context):

        if self.request.is_ajax():

            request_data = self.request.GET

            type = request_data.get('type')
            loop_cls = ModelGetter.get_model(type)
            chainable_loops_all = loop_cls.get_all_chainable()

            paginator = Paginator(chainable_loops_all, 10)

            page = request_data.get('page')
            try:
                chainable_loops = paginator.page(page)
            except PageNotAnInteger:
                chainable_loops = paginator.page(1)
            except EmptyPage:
                chainable_loops = paginator.page(paginator.num_pages)

            data = {
                "chainable_loops": chainable_loops,
            }

            template = "list_chainable.html"
            return render_to_response(template, data,
                                        context_instance=RequestContext(
                                        self.request))

        else:
            raise NotImplementedError
