#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
from django.test import TestCase
from jenkinsserver.models.jenkins_server import JenkinsServer
import jenkins
from frontend.integration_loop.models.integration_loop import IntegrationLoop


class JenkinsServerTests(TestCase):

    def setUp(self):
        self.server = JenkinsServer.objects.get(id=1)
        self.test_jenkins = jenkins.Jenkins(
            self.server.url,
            self.server.username.encode('utf-8'),
            self.server.password.encode('utf-8'))
        self.test_job_name = "test"

    def test_sync_jobs_and_builds(self):
        integration_loop = IntegrationLoop()
        integration_loop.name = self.test_job_name
        integration_loop.server = self.server
        integration_loop.branch = 'lp:linaro-ci-dashboard'
        integration_loop.precommand = 'make migrate'
        integration_loop.command = 'make test'
        integration_loop.save()
        # schedule a few builds
        integration_loop.schedule_build()
        integration_loop.schedule_build()
        self.server.sync_jobs_and_builds()
        for build in integration_loop.loopbuild_set.all():
            self.assertIsNotNone(build.duration)
            self.assertIsNot(build.duration, 0.0)

    def test_create_job_xml(self):
        loop = IntegrationLoop()
        loop.name = 'sample-test'
        loop.server = self.server
        loop.branch = 'lp:linaro-ci-dashboard'
        loop.precommand = 'cd %s' % loop.branch
        loop.command = 'make syncdb; make test'
        dest_dir = 'dest_dir'
        env_cmds = "export USER=`whoami`;\nexport HOME=/home/$USER"

        jbranch = jcommands = ''
        if loop.branch:
            if not 'lp:' in loop.branch:
                jbranch = 'bzr branch lp:%s %s' % (loop.branch, dest_dir)
            else:
                jbranch = 'bzr branch %s %s' % (loop.branch, dest_dir)

        rm_old_dest = 'rm -rf %s' % dest_dir
        dest_command = 'cur_dir=$WORKSPACE; cd ./%s' % dest_dir
        for command in [rm_old_dest, env_cmds, jbranch, dest_command,\
                        loop.precommand, loop.command]:
            if command:
                jcommands = '\n'.join([jcommands, command])

        dest_command = 'cd "$cur_dir"'
        jcommands = '\n'.join([jcommands, dest_command])
        jcommands = jcommands.strip("\n")
        jxml = self.server.create_job_xml(loop)
        self.assertIn(jcommands, jxml)

    def test_create_new_job_delete_job(self):
        loop = IntegrationLoop()
        loop.name = 'sample-test'
        loop.server = self.server
        loop.branch = 'linaro-ci-dashboard'
        loop.precommand = 'cd %s' % loop.branch
        loop.command = 'make syncdb; make test'
        jxml = self.server.create_job_xml(loop)
        self.server.create_job(loop.name, jxml)
        self.assertTrue(self.test_jenkins.job_exists(loop.name) == True)
        self.server.delete_job(loop.name)
        self.assertTrue(self.test_jenkins.job_exists(loop.name) == False)

    def test_schedule_job_build(self):
        integration_loop = IntegrationLoop()
        integration_loop.name = "test-loop"
        integration_loop.server = self.server
        integration_loop.branch = 'lp:linaro-ci-dashboard'
        integration_loop.precommand = 'make migrate'
        integration_loop.command = 'make test'
        integration_loop.save()
        build_number = self.server.schedule_job_build("test-loop")
        self.assertIs(build_number, 1)
        self.server.delete_job("test-loop")
